@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: error.c,v 1.102 2005/08/29 10:45:08 jonasw Exp $
+|| $Id: error.c,v 1.103 2006/05/10 19:43:53 mast Exp $
 */
 
 #define NO_PIKE_SHORTHAND
@@ -23,7 +23,7 @@
 #include "threads.h"
 #include "gc.h"
 
-RCSID("$Id: error.c,v 1.102 2005/08/29 10:45:08 jonasw Exp $");
+RCSID("$Id: error.c,v 1.103 2006/05/10 19:43:53 mast Exp $");
 
 #undef ATTRIBUTE
 #define ATTRIBUTE(X)
@@ -51,6 +51,8 @@ PMOD_EXPORT const char msg_too_few_args[] =
   "Too few arguments to %s().\n";
 PMOD_EXPORT const char msg_out_of_mem[] =
   "Out of memory.\n";
+PMOD_EXPORT const char msg_out_of_mem_2[] =
+  "Out of memory - failed to allocate %"PRINTSIZET"d bytes.\n";
 PMOD_EXPORT const char msg_div_by_zero[] =
   "Division by zero.\n";
 
