@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: pike_memory.c,v 1.143 2005/06/22 16:01:19 grubba Exp $
+|| $Id: pike_memory.c,v 1.147 2006/08/06 16:58:06 mast Exp $
 */
 
 #include "global.h"
@@ -27,7 +27,7 @@
 
 #include <errno.h>
 
-RCSID("$Id: pike_memory.c,v 1.143 2005/06/22 16:01:19 grubba Exp $");
+RCSID("$Id: pike_memory.c,v 1.147 2006/08/06 16:58:06 mast Exp $");
 
 /* strdup() is used by several modules, so let's provide it */
 #ifndef HAVE_STRDUP
@@ -586,7 +586,8 @@ PMOD_EXPORT void *debug_xalloc(size_t size)
   ret=(void *)malloc(size);
   if(ret) return ret;
 
-  Pike_error("Out of memory.\n");
+  Pike_error("Out of memory - failed to allocate %"PRINTSIZET"d bytes.\n",
+	     size);
   return 0;
 }
 
@@ -610,6 +611,17 @@ PMOD_EXPORT void *debug_xcalloc(size_t n, size_t s)
   return calloc(n,s);
 }
 
+PMOD_EXPORT char *debug_xstrdup(const char *src)
+{
+  char *dst = NULL;
+  if (src) {
+    int len = strlen (src) + 1;
+    dst = malloc (len);
+    MEMCPY (dst, src, len);
+  }
+  return dst;
+}
+
 char *debug_qalloc(size_t size)
 {
   char *ret;
@@ -645,7 +657,8 @@ char *debug_qalloc(size_t size)
   }
 #endif
 
-  Pike_fatal("Completely out of memory!\n");
+  Pike_fatal("Completely out of memory - "
+	     "failed to allocate %"PRINTSIZET"d bytes!\n", size);
   /* NOT_REACHED */
   return NULL;	/* Keep the compiler happy. */
 }
@@ -812,6 +825,11 @@ void mexec_free(void *ptr)
 	       ptr, mblk->magic, hdr);
   }
 #endif /* MEXEC_MAGIC */
+
+#ifdef VALGRIND_DISCARD_TRANSLATIONS
+  VALGRIND_DISCARD_TRANSLATIONS (mblk, mblk->size);
+#endif
+
   blk = (struct mexec_free_block *)mblk;
 
   next = hdr->free;
@@ -1012,7 +1030,43 @@ void *mexec_realloc(void *ptr, size_t sz)
 
   return res + 1;
 }
-#else
+
+#elif defined (VALGRIND_DISCARD_TRANSLATIONS)
+
+void *mexec_alloc (size_t sz)
+{
+  size_t *blk = malloc (sz + sizeof (size_t));
+  if (!blk) return NULL;
+  *blk = sz;
+  return blk + 1;
+}
+
+void *mexec_realloc (void *ptr, size_t sz)
+{
+  if (ptr) {
+    size_t *oldblk = ptr;
+    size_t oldsz = oldblk[-1];
+    size_t *newblk = realloc (oldblk - 1, sz + sizeof (size_t));
+    if (!newblk) return NULL;
+    if (newblk != oldblk)
+      VALGRIND_DISCARD_TRANSLATIONS (oldblk, oldsz);
+    else if (oldsz > sz)
+      VALGRIND_DISCARD_TRANSLATIONS (newblk + sz, oldsz - sz);
+    *newblk = sz;
+    return newblk + 1;
+  }
+  return mexec_malloc (sz);
+}
+
+void mexec_free (void *ptr)
+{
+  size_t *blk = ptr;
+  VALGRIND_DISCARD_TRANSLATIONS (blk, blk[-1]);
+  free (blk - 1);
+}
+
+#else  /* !(HAVE_MMAP && MEXEC_USES_MMAP) && !VALGRIND_DISCARD_TRANSLATIONS */
+
 void *mexec_alloc(size_t sz)
 {
   return malloc(sz);
@@ -1026,7 +1080,8 @@ void mexec_free(void *ptr)
 {
   free(ptr);
 }
-#endif /* HAVE_MMAP && MEXEC_USES_MMAP */
+
+#endif  /* !(HAVE_MMAP && MEXEC_USES_MMAP) && !VALGRIND_DISCARD_TRANSLATIONS */
 
 /* #define DMALLOC_TRACE */
 /* #define DMALLOC_TRACELOGSIZE	256*1024 */
@@ -1088,6 +1143,17 @@ static MUTEX_T debug_malloc_mutex;
 #undef strdup
 #undef main
 
+#ifdef USE_DL_MALLOC
+#undef ENCAPSULATE_MALLOC
+#define calloc    dlcalloc
+#define free	  dlfree
+#define malloc	  dlmalloc
+#define memalign  dlmemalign
+#define realloc	  dlrealloc
+#define valloc	  dlvalloc
+#define pvalloc	  dlpvalloc
+#endif
+
 #ifdef HAVE_DLOPEN
 #ifdef HAVE_DLFCN_H
 #include <dlfcn.h>
@@ -1373,6 +1439,8 @@ void *fake_calloc(size_t x, size_t y)
 #endif
 
 
+/* Don't understand what this is supposed to do, but it won't work
+ * with USE_DL_MALLOC. /mast */
 #ifdef WRAP
 #define malloc __real_malloc
 #define free __real_free
