@@ -1,4 +1,4 @@
-#line 1 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 1 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 /* -*- c -*-
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
@@ -114,7 +114,7 @@ struct program *Shuffle_program=0;
 
 #undef var_this_obj_Shuffle_defined
 #define var_this_obj_Shuffle_defined
-#line 101 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 101 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 /* callbacks only have the struct */
   
 #undef var_file_obj_Shuffle_defined
@@ -173,52 +173,52 @@ struct Shuffle_struct {
 #endif /* var_request_arg_Shuffle_defined */
 
 #ifdef var_current_source_Shuffle_defined
-#line 99 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 99 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct source *current_source;
 #endif /* var_current_source_Shuffle_defined */
 
 #ifdef var_last_source_Shuffle_defined
-#line 100 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 100 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct source *last_source;
 #endif /* var_last_source_Shuffle_defined */
 
 #ifdef var_this_obj_Shuffle_defined
-#line 101 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 101 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct object *this_obj;
 #endif /* var_this_obj_Shuffle_defined */
 
 #ifdef var_file_obj_Shuffle_defined
-#line 102 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 102 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct object *file_obj;
 #endif /* var_file_obj_Shuffle_defined */
 
 #ifdef var_callback_Shuffle_defined
-#line 103 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 103 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 int callback;
 #endif /* var_callback_Shuffle_defined */
 
 #ifdef var_write_callback_Shuffle_defined
-#line 104 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 104 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 int write_callback;
 #endif /* var_write_callback_Shuffle_defined */
 
 #ifdef var_fd_Shuffle_defined
-#line 106 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 106 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 int fd;
 #endif /* var_fd_Shuffle_defined */
 
 #ifdef var_sent_Shuffle_defined
-#line 107 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 107 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 int sent;
 #endif /* var_sent_Shuffle_defined */
 
 #ifdef var_state_Shuffle_defined
-#line 108 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 108 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 ShuffleState state;
 #endif /* var_state_Shuffle_defined */
 
 #ifdef var_leftovers_Shuffle_defined
-#line 110 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 110 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct data leftovers;
 #endif /* var_leftovers_Shuffle_defined */
 };
@@ -261,13 +261,13 @@ static void _send_more( int fd, struct Shuffle_struct *t );
 
   #define f_Shuffle_set_throttler_defined
 void f_Shuffle_set_throttler(INT32 args) {
-#line 150 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 150 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct object * t;
-#line 150 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 150 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 1) wrong_number_of_args_error("set_throttler",args,1);
-#line 150 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 150 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(Pike_sp[0-1].type != PIKE_T_OBJECT) SIMPLE_BAD_ARG_ERROR("set_throttler",1,"object");
-#line 150 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 150 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 debug_malloc_pass(t=Pike_sp[0-1].u.object);
 /*! @decl void set_throttler(Throttler t)
    *! Calling this function overrides the @[Shuffler] global throttler.
@@ -286,7 +286,7 @@ debug_malloc_pass(t=Pike_sp[0-1].u.object);
   }
 #define f_Shuffle_sent_data_defined
 void f_Shuffle_sent_data(INT32 args) {
-#line 165 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 165 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 0) wrong_number_of_args_error("sent_data",args,0);
 /*! @decl int sent_data()
    *! Returns the amount of data that has been sent so far.
@@ -295,13 +295,13 @@ if(args != 0) wrong_number_of_args_error("sent_data",args,0);
   {
     SHUFFLE_DEBUG2("sent_data() --> %d\n", THIS, THIS->sent );
     do { INT_TYPE ret_=(THIS->sent);  push_int(ret_); return; }while(0);
-#line 173 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 173 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 }
 
   }
 #define f_Shuffle_state_defined
 void f_Shuffle_state(INT32 args) {
-#line 175 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 175 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 0) wrong_number_of_args_error("state",args,0);
 /*! @decl int state()
    *! Returns the current state of the shuffler.
@@ -318,7 +318,7 @@ if(args != 0) wrong_number_of_args_error("state",args,0);
   {
     SHUFFLE_DEBUG2("state() --> %d\n", THIS, THIS->state );
     do { INT_TYPE ret_=(THIS->state);  push_int(ret_); return; }while(0);
-#line 191 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 191 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 }
 
   }
@@ -329,7 +329,7 @@ if(args != 0) wrong_number_of_args_error("state",args,0);
 #undef Shuffle_event_handler_defined
 #define Shuffle_event_handler_defined
 static void init_Shuffle_struct(void)
-#line 194 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 194 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 {
     THIS->leftovers.do_free = 0;
     THIS->shuffler = 0;
@@ -361,7 +361,7 @@ static void init_Shuffle_struct(void)
 #undef Shuffle_event_handler_defined
 #define Shuffle_event_handler_defined
 static void exit_Shuffle_struct(void)
-#line 219 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 219 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 {
     SHUFFLE_DEBUG1("exit()\n", THIS );
     THIS->fd = 0;
@@ -506,11 +506,11 @@ static void exit_Shuffle_struct(void)
 
   #define f_Shuffle_set_done_callback_defined
 void f_Shuffle_set_done_callback(INT32 args) {
-#line 361 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 361 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct svalue * cb;
-#line 361 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 361 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 1) wrong_number_of_args_error("set_done_callback",args,1);
-#line 361 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 361 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 cb=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
 /*! @decl void set_done_callback( function(Shuffle,int:void) cb )
     *! Sets the done callback. This function will be called when all
@@ -525,11 +525,11 @@ cb=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
   }
 #define f_Shuffle_set_request_arg_defined
 void f_Shuffle_set_request_arg(INT32 args) {
-#line 372 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 372 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct svalue * arg;
-#line 372 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 372 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 1) wrong_number_of_args_error("set_request_arg",args,1);
-#line 372 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 372 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 arg=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
 /*! @decl void set_request_arg( mixed arg )
     *!
@@ -543,7 +543,7 @@ arg=Pike_sp+0-1; dmalloc_touch_svalue(Pike_sp+0-1);
   }
   
   }
-#line 384 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 384 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 static void _give_back( struct Shuffle_struct *t, int amount )
   {
     SHUFFLE_DEBUG2("_give_back(%d)\n", t, amount );
@@ -663,14 +663,14 @@ static void _give_back( struct Shuffle_struct *t, int amount )
 
   #define f_Shuffle_send_more_callback_defined
 void f_Shuffle_send_more_callback(INT32 args) {
-#line 501 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 501 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 INT_TYPE amount;
-#line 501 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 501 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 1) wrong_number_of_args_error("send_more_callback",args,1);
-#line 501 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 501 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(Pike_sp[0-1].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("send_more_callback",1,"int");
 amount=Pike_sp[0-1].u.integer;
-#line 502 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 502 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 {
     SHUFFLE_DEBUG2("send_more_callback(%d)\n", THIS,amount );
     if( THIS->state == RUNNING )
@@ -685,17 +685,17 @@ amount=Pike_sp[0-1].u.integer;
   }
 #define f_Shuffle_write_callback_defined
 void f_Shuffle_write_callback(INT32 args) {
-#line 513 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 513 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct svalue * x;
-#line 513 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 513 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args > 1) wrong_number_of_args_error("write_callback",args,1);
 if(args > 0) { 
-#line 513 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 513 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 x=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
 }else{
 x=0;
 }
-#line 514 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 514 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 {
     SHUFFLE_DEBUG1("write_callback()\n", THIS );
     _send_more( 0,THIS );
@@ -704,23 +704,23 @@ x=0;
   }
 #define f_Shuffle_create_defined
 void f_Shuffle_create(INT32 args) {
-#line 519 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 519 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct object * fd;
 struct object * shuffler;
 struct svalue * throttler;
 struct svalue * backend;
-#line 519 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 519 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 4) wrong_number_of_args_error("create",args,4);
-#line 519 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 519 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(Pike_sp[0-4].type != PIKE_T_OBJECT) SIMPLE_BAD_ARG_ERROR("create",1,"object");
-#line 519 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 519 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 debug_malloc_pass(fd=Pike_sp[0-4].u.object);
 if(Pike_sp[1-4].type != PIKE_T_OBJECT) SIMPLE_BAD_ARG_ERROR("create",2,"object");
-#line 520 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 520 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 debug_malloc_pass(shuffler=Pike_sp[1-4].u.object);
 throttler=Pike_sp+2-4; dmalloc_touch_svalue(Pike_sp+2-4);
 backend=Pike_sp+3-4; dmalloc_touch_svalue(Pike_sp+3-4);
-#line 524 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 524 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 {
     if( (args != 4) || !shuffler || !get_storage( shuffler, Shuffler_program ) )
       Pike_error("This class cannot be instantiated directly\n");
@@ -775,7 +775,7 @@ backend=Pike_sp+3-4; dmalloc_touch_svalue(Pike_sp+3-4);
   }
 #define f_Shuffle_start_defined
 void f_Shuffle_start(INT32 args) {
-#line 575 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 575 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 0) wrong_number_of_args_error("start",args,0);
 /*! @decl void start();
     *! Start sending data from the sources.
@@ -792,7 +792,7 @@ if(args != 0) wrong_number_of_args_error("start",args,0);
   }
 #define f_Shuffle_pause_defined
 void f_Shuffle_pause(INT32 args) {
-#line 588 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 588 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 0) wrong_number_of_args_error("pause",args,0);
 /*! @decl void pause();
     *! Temporarily pause all data transmission
@@ -807,7 +807,7 @@ if(args != 0) wrong_number_of_args_error("pause",args,0);
   }
 #define f_Shuffle_stop_defined
 void f_Shuffle_stop(INT32 args) {
-#line 599 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 599 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 0) wrong_number_of_args_error("stop",args,0);
 /*! @decl void stop();
     *! Stop all data transmission, and then call the done callback
@@ -821,25 +821,25 @@ if(args != 0) wrong_number_of_args_error("stop",args,0);
   }
 #define f_Shuffle_add_source_defined
 void f_Shuffle_add_source(INT32 args) {
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct svalue * source;
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct svalue * start;
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct svalue * length;
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args < 1) wrong_number_of_args_error("add_source",args,1);
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args > 3) wrong_number_of_args_error("add_source",args,3);
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 source=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
 if(args > 1) { 
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 start=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
 }else{
 start=0;
 }if(args > 2) { 
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 length=Pike_sp+2-args; dmalloc_touch_svalue(Pike_sp+2-args);
 }else{
 length=0;
@@ -868,7 +868,7 @@ length=0;
     *! @enddl
     */
   
-#line 634 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 634 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 {
     INT64 rstart=0, rlength=-1;
     struct source *res;
@@ -995,11 +995,11 @@ struct Shuffler_struct {
 #endif /* var_sources_Shuffler_defined */
 
 #ifdef var_paused_Shuffler_defined
-#line 700 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 700 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 int paused;
 #endif /* var_paused_Shuffler_defined */
 };
-#line 704 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 704 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 static void update_sources()
   {
     push_array( THIS->sources );
@@ -1015,13 +1015,13 @@ static void update_sources()
 
   #define f_Shuffler_set_backend_defined
 void f_Shuffler_set_backend(INT32 args) {
-#line 717 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 717 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct object * b;
-#line 717 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 717 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 1) wrong_number_of_args_error("set_backend",args,1);
-#line 717 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 717 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(Pike_sp[0-1].type != PIKE_T_OBJECT) SIMPLE_BAD_ARG_ERROR("set_backend",1,"object");
-#line 717 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 717 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 debug_malloc_pass(b=Pike_sp[0-1].u.object);
 /*! @decl void set_backend( Backend b );
      *! Set the backend that will be used by all @[Shuffle] objects created
@@ -1040,12 +1040,12 @@ debug_malloc_pass(b=Pike_sp[0-1].u.object);
   }
 #define f_Shuffler_set_throttler_defined
 void f_Shuffler_set_throttler(INT32 args) {
-#line 732 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 732 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct svalue * t;
-#line 732 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 732 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args > 1) wrong_number_of_args_error("set_throttler",args,1);
 if(args > 0) { 
-#line 732 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 732 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 t=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
 }else{
 t=0;
@@ -1056,7 +1056,7 @@ t=0;
      *! 
      */
   
-#line 739 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 739 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 {
     if( THIS->throttler )
       free_object( THIS->throttler );
@@ -1071,7 +1071,7 @@ t=0;
   }
 #define f_Shuffler_pause_defined
 void f_Shuffler_pause(INT32 args) {
-#line 750 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 750 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 0) wrong_number_of_args_error("pause",args,0);
 /*! @decl void pause();
      *! Pause all @[Shuffle] objects associated with this @[Shuffler]
@@ -1092,7 +1092,7 @@ if(args != 0) wrong_number_of_args_error("pause",args,0);
   }
 #define f_Shuffler_start_defined
 void f_Shuffler_start(INT32 args) {
-#line 767 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 767 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 0) wrong_number_of_args_error("start",args,0);
 /*! @decl void start();
      *! Unpause all @[Shuffle] objects associated with this @[Shuffler]
@@ -1113,13 +1113,13 @@ if(args != 0) wrong_number_of_args_error("start",args,0);
   }
 #define f_Shuffler_cq____remove_shuffle_defined
 void f_Shuffler_cq____remove_shuffle(INT32 args) {
-#line 784 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 784 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct object * so;
-#line 784 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 784 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 1) wrong_number_of_args_error("___remove_shuffle",args,1);
-#line 784 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 784 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(Pike_sp[0-1].type != PIKE_T_OBJECT) SIMPLE_BAD_ARG_ERROR("___remove_shuffle",1,"object");
-#line 784 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 784 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 debug_malloc_pass(so=Pike_sp[0-1].u.object);
 {
     f_aggregate(1);
@@ -1135,13 +1135,13 @@ debug_malloc_pass(so=Pike_sp[0-1].u.object);
   }
 #define f_Shuffler_shuffle_defined
 void f_Shuffler_shuffle(INT32 args) {
-#line 796 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 796 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 struct object * destination;
-#line 796 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 796 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(args != 1) wrong_number_of_args_error("shuffle",args,1);
-#line 796 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 796 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 if(Pike_sp[0-1].type != PIKE_T_OBJECT) SIMPLE_BAD_ARG_ERROR("shuffle",1,"object");
-#line 796 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 796 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 debug_malloc_pass(destination=Pike_sp[0-1].u.object);
 /*! @decl Shuffle shuffle( Stdio.File destination );
      *! Create a new @[Shuffle] object.
@@ -1177,7 +1177,7 @@ debug_malloc_pass(destination=Pike_sp[0-1].u.object);
 #undef Shuffler_event_handler_defined
 #define Shuffler_event_handler_defined
 static void init_Shuffler_struct(void)
-#line 824 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 824 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 {
     THIS->sources = allocate_array(0);
   }
@@ -1210,7 +1210,7 @@ static void Shuffler_event_handler(int ev) {
 /*! @endmodule
  */
 
-#line 844 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 844 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 PIKE_MODULE_INIT
 {
   
@@ -1251,73 +1251,73 @@ PIKE_MODULE_INIT
 #endif /* Shuffle_event_handler_defined */
 
 #ifdef f_Shuffle_set_throttler_defined
-#line 150 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 150 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("set_throttler", f_Shuffle_set_throttler, tFunc(tObj,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_set_throttler_defined */
 
 #ifdef f_Shuffle_sent_data_defined
-#line 165 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 165 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("sent_data", f_Shuffle_sent_data, tFunc(tNone,"\10\200\0\0\0\177\377\377\377"), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_sent_data_defined */
 
 #ifdef f_Shuffle_state_defined
-#line 175 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 175 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("state", f_Shuffle_state, tFunc(tNone,"\10\200\0\0\0\177\377\377\377"), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_state_defined */
 
 #ifdef f_Shuffle_set_done_callback_defined
-#line 361 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 361 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("set_done_callback", f_Shuffle_set_done_callback, tFunc(tMix,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_set_done_callback_defined */
 
 #ifdef f_Shuffle_set_request_arg_defined
-#line 372 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 372 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("set_request_arg", f_Shuffle_set_request_arg, tFunc(tMix,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_set_request_arg_defined */
 
 #ifdef f_Shuffle_send_more_callback_defined
-#line 501 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 501 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("send_more_callback", f_Shuffle_send_more_callback, tFunc("\10\200\0\0\0\177\377\377\377",tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_send_more_callback_defined */
 
 #ifdef f_Shuffle_write_callback_defined
-#line 513 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 513 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("write_callback", f_Shuffle_write_callback, tFunc(tOr(tMix,tVoid),tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_write_callback_defined */
 
 #ifdef f_Shuffle_create_defined
-#line 519 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 519 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("create", f_Shuffle_create, tFunc(tObj tObj tMix tMix,tVoid), ID_STATIC, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_create_defined */
 
 #ifdef f_Shuffle_start_defined
-#line 575 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 575 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("start", f_Shuffle_start, tFunc(tNone,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_start_defined */
 
 #ifdef f_Shuffle_pause_defined
-#line 588 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 588 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("pause", f_Shuffle_pause, tFunc(tNone,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_pause_defined */
 
 #ifdef f_Shuffle_stop_defined
-#line 599 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 599 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("stop", f_Shuffle_stop, tFunc(tNone,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_stop_defined */
 
 #ifdef f_Shuffle_add_source_defined
-#line 609 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 609 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("add_source", f_Shuffle_add_source, tFunc(tMix tOr(tMix,tVoid) tOr(tMix,tVoid),tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffle_add_source_defined */
@@ -1359,37 +1359,37 @@ PIKE_MODULE_INIT
 #endif /* Shuffler_event_handler_defined */
 
 #ifdef f_Shuffler_set_backend_defined
-#line 717 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 717 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("set_backend", f_Shuffler_set_backend, tFunc(tObj,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffler_set_backend_defined */
 
 #ifdef f_Shuffler_set_throttler_defined
-#line 732 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 732 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("set_throttler", f_Shuffler_set_throttler, tFunc(tOr(tObj,tVoid),tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffler_set_throttler_defined */
 
 #ifdef f_Shuffler_pause_defined
-#line 750 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 750 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("pause", f_Shuffler_pause, tFunc(tNone,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffler_pause_defined */
 
 #ifdef f_Shuffler_start_defined
-#line 767 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 767 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("start", f_Shuffler_start, tFunc(tNone,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffler_start_defined */
 
 #ifdef f_Shuffler_cq____remove_shuffle_defined
-#line 784 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 784 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("___remove_shuffle", f_Shuffler_cq____remove_shuffle, tFunc(tObj,tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffler_cq____remove_shuffle_defined */
 
 #ifdef f_Shuffler_shuffle_defined
-#line 796 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 796 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
   ADD_FUNCTION2("shuffle", f_Shuffler_shuffle, tFunc(tObj,tObj), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_Shuffler_shuffle_defined */
@@ -1397,7 +1397,7 @@ PIKE_MODULE_INIT
   add_program_constant("Shuffler",Shuffler_program,0);
 
 #endif /* class_Shuffler_defined */
-#line 846 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 846 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 ;
   sources_init();
   add_integer_constant( "INITIAL", INITIAL, 0 );
@@ -1427,7 +1427,7 @@ PIKE_MODULE_EXIT
   }
 
 #endif /* class_Shuffler_defined */
-#line 859 "/home/distmaker/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
+#line 859 "/home/dist/tmp/build/pike.srcbuild/../pike-cvs/src/post_modules/Shuffler/Shuffler.cmod"
 ;
   sources_exit();
 }
