@@ -2,7 +2,7 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: svalue.c,v 1.161 2004/09/25 19:21:50 grubba Exp $
+|| $Id: svalue.c,v 1.164 2006/06/21 11:33:02 mast Exp $
 */
 
 #include "global.h"
@@ -72,7 +72,7 @@ static int pike_isnan(double x)
 #define PIKE_ISUNORDERED(X,Y) (PIKE_ISNAN(X)||PIKE_ISNAN(Y))
 #endif /* HAVE_ISUNORDERED */
 
-RCSID("$Id: svalue.c,v 1.161 2004/09/25 19:21:50 grubba Exp $");
+RCSID("$Id: svalue.c,v 1.164 2006/06/21 11:33:02 mast Exp $");
 
 struct svalue dest_ob_zero = {
   T_INT, 0,
@@ -1160,6 +1160,10 @@ PMOD_EXPORT void describe_svalue(const struct svalue *s,int indent,struct proces
 {
   char buf[50];
 
+  /* This needs to be a bit lower than LOW_C_STACK_MARGIN so that the
+   * the raw error can be printed in exit_on_error. */
+  check_c_stack(250);
+
   check_type(s->type);
   check_refs(s);
 
@@ -1288,7 +1292,8 @@ PMOD_EXPORT void describe_svalue(const struct svalue *s,int indent,struct proces
 	  if (id) name = id->name;
 
 	  if(name && (prog->flags & PROGRAM_FINISHED) &&
-	     Pike_interpreter.evaluator_stack && !Pike_in_gc &&
+	     Pike_interpreter.evaluator_stack &&
+	     (!Pike_in_gc || Pike_in_gc >= GC_PASS_FREE) &&
 	     master_object) {
 	    DECLARE_CYCLIC();
 	    debug_malloc_touch(obj);
@@ -1374,7 +1379,9 @@ PMOD_EXPORT void describe_svalue(const struct svalue *s,int indent,struct proces
 	my_strcat("0");
       else {
 	if ((prog->flags & PROGRAM_FINISHED) &&
-	    Pike_interpreter.evaluator_stack && !Pike_in_gc && master_object) {
+	    Pike_interpreter.evaluator_stack &&
+	    (!Pike_in_gc || Pike_in_gc >= GC_PASS_FREE) &&
+	    master_object) {
 	  DECLARE_CYCLIC();
 	  int fun=FIND_LFUN(prog, LFUN__SPRINTF);
 	  debug_malloc_touch(prog);
@@ -1501,7 +1508,9 @@ PMOD_EXPORT void describe_svalue(const struct svalue *s,int indent,struct proces
       struct program *prog = s->u.program;
 
       if((prog->flags & PROGRAM_FINISHED) &&
-	 Pike_interpreter.evaluator_stack && !Pike_in_gc && master_object) {
+	 Pike_interpreter.evaluator_stack &&
+	 (!Pike_in_gc || Pike_in_gc >= GC_PASS_FREE) &&
+	 master_object) {
 	DECLARE_CYCLIC();
 	debug_malloc_touch(prog);
 	if (!BEGIN_CYCLIC(prog, 0)) {
